Worldman Games System
=====================

**PyPI repository**: [wg-system](https://pypi.org/project/wg-system/)

This is the backend of system that is used internally for managing [Worldman Games](http://wmgames.ee) events.

Contributions (issues or merge requests) are welcome!